===================
MediaWiki Utilities
===================
 
MediaWiki Utilities is an open source (MIT Licensed) library developed by Aaron Halfaker for extracting and processing data from MediaWiki installations, slave databases and xml dumps.

**Instal with pip:** ``pip install mediawiki-utilities``

**Note:** *Use of this library requires Python 3 or later.*

**Documentation:** http://pythonhosted.org/mediawiki-utilities/

About the author
================
:name: 
	Aaron Halfaker
:email:
	aaron.halfaker@gmail.com
:website:
	http://halfaker.info --
	http://en.wikipedia.org/wiki/User:EpochFail

Contributors
============
None yet.  See http://github.com/halfak/mediawiki-utilities.  Pull requests are encouraged.
